==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/FeatureLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.FeatureLinksAllOfDependencies;
import com.okta.sdk.resource.model.FeatureLinksAllOfDependents;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * FeatureLinks
 */
@JsonPropertyOrder({ FeatureLinks.JSON_PROPERTY_SELF, FeatureLinks.JSON_PROPERTY_DEPENDENTS,
        FeatureLinks.JSON_PROPERTY_DEPENDENCIES })
@JsonTypeName("Feature__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class FeatureLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_DEPENDENTS = "dependents";
    private FeatureLinksAllOfDependents dependents;

    public static final String JSON_PROPERTY_DEPENDENCIES = "dependencies";
    private FeatureLinksAllOfDependencies dependencies;

    public FeatureLinks() {
    }

    public FeatureLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public FeatureLinks dependents(FeatureLinksAllOfDependents dependents) {

        this.dependents = dependents;
        return this;
    }

    /**
     * Get dependents
     *
     * @return dependents
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEPENDENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FeatureLinksAllOfDependents getDependents() {
        return dependents;
    }

    @JsonProperty(JSON_PROPERTY_DEPENDENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDependents(FeatureLinksAllOfDependents dependents) {
        this.dependents = dependents;
    }

    public FeatureLinks dependencies(FeatureLinksAllOfDependencies dependencies) {

        this.dependencies = dependencies;
        return this;
    }

    /**
     * Get dependencies
     *
     * @return dependencies
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEPENDENCIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FeatureLinksAllOfDependencies getDependencies() {
        return dependencies;
    }

    @JsonProperty(JSON_PROPERTY_DEPENDENCIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDependencies(FeatureLinksAllOfDependencies dependencies) {
        this.dependencies = dependencies;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FeatureLinks featureLinks = (FeatureLinks) o;
        return Objects.equals(this.self, featureLinks.self) && Objects.equals(this.dependents, featureLinks.dependents)
                && Objects.equals(this.dependencies, featureLinks.dependencies);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, dependents, dependencies);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class FeatureLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    dependents: ").append(toIndentedString(dependents)).append("\n");
        sb.append("    dependencies: ").append(toIndentedString(dependencies)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/FeatureLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.FeatureLinksAllOfDependencies;
import com.okta.sdk.resource.model.FeatureLinksAllOfDependents;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * FeatureLinks
 */
@JsonPropertyOrder({ FeatureLinks.JSON_PROPERTY_SELF, FeatureLinks.JSON_PROPERTY_DEPENDENTS,
        FeatureLinks.JSON_PROPERTY_DEPENDENCIES })
@JsonTypeName("Feature__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class FeatureLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_DEPENDENTS = "dependents";
    private FeatureLinksAllOfDependents dependents;

    public static final String JSON_PROPERTY_DEPENDENCIES = "dependencies";
    private FeatureLinksAllOfDependencies dependencies;

    public FeatureLinks() {
    }

    public FeatureLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public FeatureLinks dependents(FeatureLinksAllOfDependents dependents) {

        this.dependents = dependents;
        return this;
    }

    /**
     * Get dependents
     *
     * @return dependents
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEPENDENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FeatureLinksAllOfDependents getDependents() {
        return dependents;
    }

    @JsonProperty(JSON_PROPERTY_DEPENDENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDependents(FeatureLinksAllOfDependents dependents) {
        this.dependents = dependents;
    }

    public FeatureLinks dependencies(FeatureLinksAllOfDependencies dependencies) {

        this.dependencies = dependencies;
        return this;
    }

    /**
     * Get dependencies
     *
     * @return dependencies
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEPENDENCIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FeatureLinksAllOfDependencies getDependencies() {
        return dependencies;
    }

    @JsonProperty(JSON_PROPERTY_DEPENDENCIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDependencies(FeatureLinksAllOfDependencies dependencies) {
        this.dependencies = dependencies;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FeatureLinks featureLinks = (FeatureLinks) o;
        return Objects.equals(this.self, featureLinks.self) && Objects.equals(this.dependents, featureLinks.dependents)
                && Objects.equals(this.dependencies, featureLinks.dependencies);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, dependents, dependencies);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class FeatureLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    dependents: ").append(toIndentedString(dependents)).append("\n");
        sb.append("    dependencies: ").append(toIndentedString(dependencies)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
